Calculate the relative proportion of the items of a given vector
Source:R/relative_proportion.R
relative_proportion.RdCalculate the relative proportion of the items of a given vector
R/relative_proportion.R
relative_proportion.RdCalculate the relative proportion of the items of a given vector