Reduce Xfiber tracks to vectors connecting the two endpoints
Source:R/find_track_ends.R
find_track_ends.RdThis function finds the (x, y, z) coordinates of the starting and ending points of an Xfiber tracks object read by `read_xfiber_xml()`.
Examples
D <- read_xfiber_xml(system.file("extdata",
"AV069_SC.xml",
package = "MuscleTernary")) |>
dplyr::mutate(muscle = "SC")
ends <- find_track_ends(D)